/* -*- mode: c++; indent-tabs-mode: nil -*- */
/** @file SSH2Base.qpp defines the SSH2Base class */
/*
  QC_SSH2Base.qpp

  libssh2 ssh2 client integration in Qore

  Qore Programming Language

  Copyright 2009 Wolfgang Ritzinger

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "QC_SSH2Base.h"
#include "SSH2Client.h"

static const char *SSH2_CONNECTED = "SSH2-CONNECTED";
/* Qore class Qore::SSH2::SSH2Base */

qore_classid_t CID_SSH2BASE;
QoreClass* QC_SSH2BASE;

// nothing SSH2Base::connect(timeout timeout = 1m){}
static AbstractQoreNode* SSH2Base_connect_Vt(QoreObject* self, SSH2Client* myself, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 61 "QC_SSH2Base.qpp"
    myself->connect(timeout, xsink);
    return 0;
}

// bool SSH2Base::connected(){}
static bool SSH2Base_connected(QoreObject* self, SSH2Client* myself, const QoreListNode* args, ExceptionSink* xsink) {
# 128 "QC_SSH2Base.qpp"
    return myself->ssh_connected();
}

// SSH2Base::constructor() {}
static void SSH2Base_constructor(QoreObject* self, const QoreListNode* args, ExceptionSink* xsink) {
# 43 "QC_SSH2Base.qpp"
xsink->raiseException("SSH2BASE-CONSTRUCTOR-ERROR", "this class is an abstract class and cannot be instantiated directly or directly inherited by a user-defined class");
}

// nothing SSH2Base::disconnect(timeout timeout = 1m){}
static AbstractQoreNode* SSH2Base_disconnect_Vt(QoreObject* self, SSH2Client* myself, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 72 "QC_SSH2Base.qpp"
    myself->disconnect(0, timeout, xsink);
    return 0;
}

// nothing SSH2Base::setKeys(string priv_key, *string pub_key){}
static AbstractQoreNode* SSH2Base_setKeys_VsNs(QoreObject* self, SSH2Client* myself, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* priv_key = HARD_QORE_STRING(args, 0);
    const QoreStringNode* pub_key = reinterpret_cast<const QoreStringNode*>(get_param(args, 1));
# 116 "QC_SSH2Base.qpp"
    myself->setKeys(priv_key->getBuffer(), pub_key ? pub_key->getBuffer() : 0, xsink);
    return 0;
}

// nothing SSH2Base::setPassword(string pass){}
static AbstractQoreNode* SSH2Base_setPassword_Vs(QoreObject* self, SSH2Client* myself, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* pass = HARD_QORE_STRING(args, 0);
# 97 "QC_SSH2Base.qpp"
    if (myself->setPassword(pass->getBuffer()))
      xsink->raiseException(SSH2_CONNECTED, "usage of SSH2Base::setPassword() is not allowed when connected");
    return 0;
}

// nothing SSH2Base::setUser(string user){}
static AbstractQoreNode* SSH2Base_setUser_Vs(QoreObject* self, SSH2Client* myself, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* user = HARD_QORE_STRING(args, 0);
# 84 "QC_SSH2Base.qpp"
    if (myself->setUser(user->getBuffer()))
      xsink->raiseException(SSH2_CONNECTED, "usage of SSH2Base::setUser() is not allowed when connected");
    return 0;
}

DLLLOCAL void preinitSSH2BaseClass() {
    QC_SSH2BASE = new QoreClass("SSH2Base", QDOM_NETWORK);
    CID_SSH2BASE = QC_SSH2BASE->getID();
    QC_SSH2BASE->setSystem();
}

DLLLOCAL QoreClass* initSSH2BaseClass(QoreNamespace& ns) {
    if (!QC_SSH2BASE)
        preinitSSH2BaseClass();

    // nothing SSH2Base::connect(timeout timeout = 1m){}
    QC_SSH2BASE->addMethodExtended3("connect", (q_method_t)SSH2Base_connect_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, DateTimeNode::makeRelative(0, 0, 0, 0, 1, 0, 0), "timeout");

    // bool SSH2Base::connected(){}
    QC_SSH2BASE->addMethodExtended3("connected", (q_method_bool_t)SSH2Base_connected, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // SSH2Base::constructor() {}
    QC_SSH2BASE->setConstructorExtended3(SSH2Base_constructor, false, QC_NO_FLAGS, QDOM_DEFAULT);

    // nothing SSH2Base::disconnect(timeout timeout = 1m){}
    QC_SSH2BASE->addMethodExtended3("disconnect", (q_method_t)SSH2Base_disconnect_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, DateTimeNode::makeRelative(0, 0, 0, 0, 1, 0, 0), "timeout");

    // nothing SSH2Base::setKeys(string priv_key, *string pub_key){}
    QC_SSH2BASE->addMethodExtended3("setKeys", (q_method_t)SSH2Base_setKeys_VsNs, false, QC_NO_FLAGS, QDOM_FILESYSTEM, nothingTypeInfo, 2, stringTypeInfo, NULL, "priv_key", stringOrNothingTypeInfo, NULL, "pub_key");

    // nothing SSH2Base::setPassword(string pass){}
    QC_SSH2BASE->addMethodExtended3("setPassword", (q_method_t)SSH2Base_setPassword_Vs, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, NULL, "pass");

    // nothing SSH2Base::setUser(string user){}
    QC_SSH2BASE->addMethodExtended3("setUser", (q_method_t)SSH2Base_setUser_Vs, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, NULL, "user");

    return QC_SSH2BASE;
}
