/* -*- mode: c++; indent-tabs-mode: nil -*- */
/** @file SSH2Channel.qpp defines the SSH2Channel class */
/*
  QC_SSH2Channel.qpp

  libssh2 ssh2 channel integration into qore

  Copyright 2010 Wolfgang Ritzinger

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "SSH2Channel.h"
/* Qore class Qore::SSH2::SSH2Channel */

qore_classid_t CID_SSH2CHANNEL;
QoreClass* QC_SSH2CHANNEL;

// nothing SSH2Channel::close(timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_close_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 350 "QC_SSH2Channel.qpp"
    c->close(xsink, timeout);
    return 0;
}

// SSH2Channel::constructor() {}
static void SSH2Channel_constructor(QoreObject* self, const QoreListNode* args, ExceptionSink* xsink) {
# 37 "QC_SSH2Channel.qpp"
xsink->raiseException("SSH2CHANNEL-CONSTRUCTOR-ERROR", "this class cannot be directly constructed but is created from methods in the SSH2Client class (ex: SSH2Client::openSessionChannel())");
}

// SSH2Channel::copy() {}
static void SSH2Channel_copy(QoreObject* self, QoreObject* old, SSH2Channel* c, ExceptionSink* xsink) {
# 44 "QC_SSH2Channel.qpp"
xsink->raiseException("SSH2CHANNEL-COPY-ERROR", "copying SSH2Channel objects is not supported");
}

// SSH2Channel::destructor() {}
static void SSH2Channel_destructor(QoreObject* self, SSH2Channel* c, ExceptionSink* xsink) {
# 51 "QC_SSH2Channel.qpp"
c->destructor();
   c->deref();
}

// bool SSH2Channel::eof(){}
static bool SSH2Channel_eof(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
# 135 "QC_SSH2Channel.qpp"
    bool b = c->eof(xsink);
   return *xsink ? get_bool_node(b) : 0;
}

// nothing SSH2Channel::exec(string command, timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_exec_VsVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* command = HARD_QORE_STRING(args, 0);
    int64 timeout = HARD_QORE_INT(args, 1);
# 180 "QC_SSH2Channel.qpp"
    c->exec(command->getBuffer(), timeout, xsink);
    return 0;
}

// nothing SSH2Channel::extendedDataIgnore(timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_extendedDataIgnore_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 458 "QC_SSH2Channel.qpp"
    c->extendedDataIgnore(xsink, timeout);
    return 0;
}

// nothing SSH2Channel::extendedDataMerge(timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_extendedDataMerge_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 444 "QC_SSH2Channel.qpp"
    c->extendedDataMerge(xsink, timeout);
    return 0;
}

// nothing SSH2Channel::extendedDataNormal(timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_extendedDataNormal_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 430 "QC_SSH2Channel.qpp"
    c->extendedDataNormal(xsink, timeout);
    return 0;
}

// string SSH2Channel::getEncoding(){}
static AbstractQoreNode* SSH2Channel_getEncoding(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
# 416 "QC_SSH2Channel.qpp"
    return new QoreStringNode(c->getEncoding()->getCode());
}

// int SSH2Channel::getExitStatus(){}
static int64 SSH2Channel_getExitStatus(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
# 378 "QC_SSH2Channel.qpp"
    return c->getExitStatus(xsink);
}

// string SSH2Channel::read(softint stream_id = 0, timeout timeout = 10000){}
static AbstractQoreNode* SSH2Channel_read_viVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 stream_id = HARD_QORE_INT(args, 0);
    int64 timeout = HARD_QORE_INT(args, 1);
# 211 "QC_SSH2Channel.qpp"
    if (stream_id < 0) {
      xsink->raiseException("SSH2CHANNEL-READ-ERROR", "expecting non-negative integer for stream id as optional first argument to SSH2Channel::read([streamid], [timeout_ms]), got "QLLD" instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }
   return c->read(xsink, stream_id, timeout);
}

// binary SSH2Channel::readBinary(softint stream_id = 0, timeout timeout = 10000){}
static AbstractQoreNode* SSH2Channel_readBinary_viVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 stream_id = HARD_QORE_INT(args, 0);
    int64 timeout = HARD_QORE_INT(args, 1);
# 230 "QC_SSH2Channel.qpp"
    if (stream_id < 0) {
      xsink->raiseException("SSH2CHANNEL-READBINARY-ERROR", "expecting non-negative integer for stream id as optional first argument to SSH2Channel::readBinary([streamid], [timeout_ms]), got "QLLD" instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }
   return c->readBinary(xsink, stream_id, timeout);
}

// binary SSH2Channel::readBinaryBlock(softint size, softint stream_id = 0, timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_readBinaryBlock_viviVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 size = HARD_QORE_INT(args, 0);
    int64 stream_id = HARD_QORE_INT(args, 1);
    int64 timeout = HARD_QORE_INT(args, 2);
# 280 "QC_SSH2Channel.qpp"
    static const char *SSH2CHANNEL_READBINARYBLOCK_ERROR = "SSH2CHANNEL-READBINARYBLOCK-ERROR";
   if (size <= 0) {
      xsink->raiseException(SSH2CHANNEL_READBINARYBLOCK_ERROR, "expecting a positive size for the block size to read, got "QLLD" instead; use SSH2Channel::readBinary() to read available data without a block size", size);
      return 0;
   }
   if (stream_id < 0) {
      xsink->raiseException(SSH2CHANNEL_READBINARYBLOCK_ERROR, "expecting non-negative integer for stream id as optional second argument to SSH2Channel::readBinaryBlock(blocksize, [streamid], [timeout_ms]), got "QLLD" instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }
   return c->readBinary(size, stream_id, timeout, xsink);
}

// string SSH2Channel::readBlock(softint size, softint stream_id = 0, timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_readBlock_viviVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 size = HARD_QORE_INT(args, 0);
    int64 stream_id = HARD_QORE_INT(args, 1);
    int64 timeout = HARD_QORE_INT(args, 2);
# 252 "QC_SSH2Channel.qpp"
    static const char *SSH2CHANNEL_READBLOCK_ERROR = "SSH2CHANNEL-READBLOCK-ERROR";
   if (size <= 0) {
      xsink->raiseException(SSH2CHANNEL_READBLOCK_ERROR, "expecting a positive size for the block size to read, got "QLLD" instead; use SSH2Channel::read() to read available data without a block size", size);
      return 0;
   }
   if (stream_id < 0) {
      xsink->raiseException(SSH2CHANNEL_READBLOCK_ERROR, "expecting non-negative integer for stream id as optional second argument to SSH2Channel::readBlock(blocksize, [streamid], [timeout_ms]), got "QLLD" instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }

   return c->read(size, stream_id, timeout, xsink);
}

// nothing SSH2Channel::requestPty(string term = "vanilla", string modes = "", softint width = LIBSSH2_TERM_WIDTH, softint height = LIBSSH2_TERM_HEIGHT, softint width_px = LIBSSH2_TERM_WIDTH_PX, softint height_px = LIBSSH2_TERM_HEIGHT_PX, timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_requestPty_VsVsviviviviVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* term = HARD_QORE_STRING(args, 0);
    const QoreStringNode* modes = HARD_QORE_STRING(args, 1);
    int64 width = HARD_QORE_INT(args, 2);
    int64 height = HARD_QORE_INT(args, 3);
    int64 width_px = HARD_QORE_INT(args, 4);
    int64 height_px = HARD_QORE_INT(args, 5);
    int64 timeout = HARD_QORE_INT(args, 6);
# 89 "QC_SSH2Channel.qpp"
    static const char *SSH2CHANNEL_REQUESTPTY_ERR = "SSH2CHANNEL-REQUESTPTY-ERROR";

   if (width < 0) {
      xsink->raiseException(SSH2CHANNEL_REQUESTPTY_ERR, "terminal width given as the optional third argument to SSH2Channel::requestPty() must be non-negative; value given: %d", width);
      return 0;
   }
   if (height < 0) {
      xsink->raiseException(SSH2CHANNEL_REQUESTPTY_ERR, "terminal height given as the optional fourth argument to SSH2Channel::requestPty() must be non-negative; value given: %d", height);
      return 0;
   }
   if (width_px < 0) {
      xsink->raiseException(SSH2CHANNEL_REQUESTPTY_ERR, "terminal pixel width given as the optional fifth argument to SSH2Channel::requestPty() must be non-negative; value given: %d", width_px);
      return 0;
   }
   if (height_px < 0) {
      xsink->raiseException(SSH2CHANNEL_REQUESTPTY_ERR, "terminal pixel height given as the optional sixth argument to SSH2Channel::requestPty() must be non-negative; value given: %d", height_px);
      return 0;
   }

   c->requestPty(xsink, *term, *modes, (int)width, (int)height, (int)width_px, (int)height_px, timeout);
   return 0;
}

// nothing SSH2Channel::requestX11Forwarding(softint screen_no = 0, bool single_connection = False, string auth_proto = "", string auth_cookie = "", timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_requestX11Forwarding_viVbVsVsVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 screen_no = HARD_QORE_INT(args, 0);
    bool single_connection = HARD_QORE_BOOL(args, 1);
    const QoreStringNode* auth_proto = HARD_QORE_STRING(args, 2);
    const QoreStringNode* auth_cookie = HARD_QORE_STRING(args, 3);
    int64 timeout = HARD_QORE_INT(args, 4);
# 396 "QC_SSH2Channel.qpp"
    c->requestX11Forwarding(xsink, (int)screen_no, single_connection, auth_proto->strlen() ? auth_proto->getBuffer() : 0, auth_cookie->strlen() ? auth_cookie->getBuffer() : 0, timeout);
    return 0;
}

// nothing SSH2Channel::sendEof(timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_sendEof_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 150 "QC_SSH2Channel.qpp"
    c->sendEof(xsink, timeout);
    return 0;
}

// nothing SSH2Channel::setEncoding(string encoding){}
static AbstractQoreNode* SSH2Channel_setEncoding_Vs(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* encoding = HARD_QORE_STRING(args, 0);
# 406 "QC_SSH2Channel.qpp"
    c->setEncoding(QEM.findCreate(encoding));
    return 0;
}

// nothing SSH2Channel::setenv(string var, string value, timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_setenv_VsVsVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* var = HARD_QORE_STRING(args, 0);
    const QoreStringNode* value = HARD_QORE_STRING(args, 1);
    int64 timeout = HARD_QORE_INT(args, 2);
# 68 "QC_SSH2Channel.qpp"
    c->setenv(var->getBuffer(), value->getBuffer(), timeout, xsink);
   return 0;
}

// nothing SSH2Channel::shell(timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_shell_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 123 "QC_SSH2Channel.qpp"
    c->shell(xsink, timeout);
    return 0;
}

// nothing SSH2Channel::subsystem(string command, timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_subsystem_VsVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* command = HARD_QORE_STRING(args, 0);
    int64 timeout = HARD_QORE_INT(args, 1);
# 196 "QC_SSH2Channel.qpp"
    c->subsystem(command->getBuffer(), timeout, xsink);
    return 0;
}

// nothing SSH2Channel::waitClosed(timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_waitClosed_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 364 "QC_SSH2Channel.qpp"
    c->waitClosed(xsink, timeout);
    return 0;
}

// nothing SSH2Channel::waitEof(timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_waitEof_Vt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    int64 timeout = HARD_QORE_INT(args, 0);
# 164 "QC_SSH2Channel.qpp"
    c->waitEof(xsink, timeout);
    return 0;
}

// nothing SSH2Channel::write(data data, softint stream_id = 0, timeout timeout = -1){}
static AbstractQoreNode* SSH2Channel_write_VDviVt(QoreObject* self, SSH2Channel* c, const QoreListNode* args, ExceptionSink* xsink) {
    const AbstractQoreNode* data = get_param(args, 0);
    int64 stream_id = HARD_QORE_INT(args, 1);
    int64 timeout = HARD_QORE_INT(args, 2);
# 305 "QC_SSH2Channel.qpp"
    static const char *SSH2CHANNEL_WRITE_ERROR = "SSH2CHANNEL-WRITE-ERROR";
   const void *buf = 0;
   qore_size_t buflen;

   qore_type_t t = data->getType();

   TempEncodingHelper tmp;
   if (t == NT_STRING) {
      const QoreStringNode *str = reinterpret_cast<const QoreStringNode*>(data);
      tmp.set(str, c->getEncoding(), xsink);
      if (*xsink)
	 return 0;

      buf = tmp->getBuffer();
      buflen = tmp->strlen();
   }
   else {
      const BinaryNode *b = reinterpret_cast<const BinaryNode*>(data);
      buf = b->getPtr();
      buflen = b->size();
   }

   // ignore zero-length writes
   if (!buflen)
      return 0;

   if (stream_id < 0) {
      xsink->raiseException(SSH2CHANNEL_WRITE_ERROR, "expecting non-negative integer for stream id as optional second argument to SSH2Channel::write(data $data, softint $streamid, $timeout), got "QLLD" instead; use 0 for stdin, 1 for stderr", stream_id);
      return 0;
   }

   c->write(xsink, buf, buflen, stream_id, timeout);
    return 0;
}

DLLLOCAL void preinitSSH2ChannelClass() {
    QC_SSH2CHANNEL = new QoreClass("SSH2Channel", QDOM_NETWORK);
    CID_SSH2CHANNEL = QC_SSH2CHANNEL->getID();
    QC_SSH2CHANNEL->setSystem();
}

DLLLOCAL QoreClass* initSSH2ChannelClass(QoreNamespace& ns) {
    if (!QC_SSH2CHANNEL)
        preinitSSH2ChannelClass();

    // nothing SSH2Channel::close(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("close", (q_method_t)SSH2Channel_close_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // SSH2Channel::constructor() {}
    QC_SSH2CHANNEL->setConstructorExtended3(SSH2Channel_constructor, false, QC_NO_FLAGS, QDOM_DEFAULT);

    // SSH2Channel::copy() {}
    QC_SSH2CHANNEL->setCopy((q_copy_t)SSH2Channel_copy);

    // SSH2Channel::destructor() {}
    QC_SSH2CHANNEL->setDestructor((q_destructor_t)SSH2Channel_destructor);

    // bool SSH2Channel::eof(){}
    QC_SSH2CHANNEL->addMethodExtended3("eof", (q_method_bool_t)SSH2Channel_eof, false, QC_NO_FLAGS, QDOM_DEFAULT, boolTypeInfo);

    // nothing SSH2Channel::exec(string command, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("exec", (q_method_t)SSH2Channel_exec_VsVt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 2, stringTypeInfo, NULL, "command", timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::extendedDataIgnore(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("extendedDataIgnore", (q_method_t)SSH2Channel_extendedDataIgnore_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::extendedDataMerge(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("extendedDataMerge", (q_method_t)SSH2Channel_extendedDataMerge_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::extendedDataNormal(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("extendedDataNormal", (q_method_t)SSH2Channel_extendedDataNormal_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // string SSH2Channel::getEncoding(){}
    QC_SSH2CHANNEL->addMethodExtended3("getEncoding", (q_method_t)SSH2Channel_getEncoding, false, QC_CONSTANT, QDOM_DEFAULT, stringTypeInfo);

    // int SSH2Channel::getExitStatus(){}
    QC_SSH2CHANNEL->addMethodExtended3("getExitStatus", (q_method_int64_t)SSH2Channel_getExitStatus, false, QC_NO_FLAGS, QDOM_DEFAULT, bigIntTypeInfo);

    // string SSH2Channel::read(softint stream_id = 0, timeout timeout = 10000){}
    QC_SSH2CHANNEL->addMethodExtended3("read", (q_method_t)SSH2Channel_read_viVt, false, QC_NO_FLAGS, QDOM_DEFAULT, stringTypeInfo, 2, softBigIntTypeInfo, zero(), "stream_id", timeoutTypeInfo, new QoreBigIntNode(10000), "timeout");

    // binary SSH2Channel::readBinary(softint stream_id = 0, timeout timeout = 10000){}
    QC_SSH2CHANNEL->addMethodExtended3("readBinary", (q_method_t)SSH2Channel_readBinary_viVt, false, QC_NO_FLAGS, QDOM_DEFAULT, binaryTypeInfo, 2, softBigIntTypeInfo, zero(), "stream_id", timeoutTypeInfo, new QoreBigIntNode(10000), "timeout");

    // binary SSH2Channel::readBinaryBlock(softint size, softint stream_id = 0, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("readBinaryBlock", (q_method_t)SSH2Channel_readBinaryBlock_viviVt, false, QC_NO_FLAGS, QDOM_DEFAULT, binaryTypeInfo, 3, softBigIntTypeInfo, NULL, "size", softBigIntTypeInfo, zero(), "stream_id", timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // string SSH2Channel::readBlock(softint size, softint stream_id = 0, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("readBlock", (q_method_t)SSH2Channel_readBlock_viviVt, false, QC_NO_FLAGS, QDOM_DEFAULT, stringTypeInfo, 3, softBigIntTypeInfo, NULL, "size", softBigIntTypeInfo, zero(), "stream_id", timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::requestPty(string term = "vanilla", string modes = "", softint width = LIBSSH2_TERM_WIDTH, softint height = LIBSSH2_TERM_HEIGHT, softint width_px = LIBSSH2_TERM_WIDTH_PX, softint height_px = LIBSSH2_TERM_HEIGHT_PX, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("requestPty", (q_method_t)SSH2Channel_requestPty_VsVsviviviviVt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 7, stringTypeInfo, new QoreStringNode("vanilla"), "term", stringTypeInfo, new QoreStringNode(""), "modes", softBigIntTypeInfo, new QoreBigIntNode(LIBSSH2_TERM_WIDTH), "width", softBigIntTypeInfo, new QoreBigIntNode(LIBSSH2_TERM_HEIGHT), "height", softBigIntTypeInfo, new QoreBigIntNode(LIBSSH2_TERM_WIDTH_PX), "width_px", softBigIntTypeInfo, new QoreBigIntNode(LIBSSH2_TERM_HEIGHT_PX), "height_px", timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::requestX11Forwarding(softint screen_no = 0, bool single_connection = False, string auth_proto = "", string auth_cookie = "", timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("requestX11Forwarding", (q_method_t)SSH2Channel_requestX11Forwarding_viVbVsVsVt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 5, softBigIntTypeInfo, zero(), "screen_no", boolTypeInfo, &False, "single_connection", stringTypeInfo, new QoreStringNode(""), "auth_proto", stringTypeInfo, new QoreStringNode(""), "auth_cookie", timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::sendEof(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("sendEof", (q_method_t)SSH2Channel_sendEof_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::setEncoding(string encoding){}
    QC_SSH2CHANNEL->addMethodExtended3("setEncoding", (q_method_t)SSH2Channel_setEncoding_Vs, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, NULL, "encoding");

    // nothing SSH2Channel::setenv(string var, string value, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("setenv", (q_method_t)SSH2Channel_setenv_VsVsVt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 3, stringTypeInfo, NULL, "var", stringTypeInfo, NULL, "value", timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::shell(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("shell", (q_method_t)SSH2Channel_shell_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::subsystem(string command, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("subsystem", (q_method_t)SSH2Channel_subsystem_VsVt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 2, stringTypeInfo, NULL, "command", timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::waitClosed(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("waitClosed", (q_method_t)SSH2Channel_waitClosed_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::waitEof(timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("waitEof", (q_method_t)SSH2Channel_waitEof_Vt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    // nothing SSH2Channel::write(data data, softint stream_id = 0, timeout timeout = -1){}
    QC_SSH2CHANNEL->addMethodExtended3("write", (q_method_t)SSH2Channel_write_VDviVt, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 3, dataTypeInfo, NULL, "data", softBigIntTypeInfo, zero(), "stream_id", timeoutTypeInfo, new QoreBigIntNode(-1), "timeout");

    return QC_SSH2CHANNEL;
}
